%define anolis_release 1
%global pypi_name dnspython

%bcond_with trio
%bcond_with doh

Name:           python-dns
Version:        2.4.1
Release:        %{anolis_release}%{?dist}
Summary:        DNS toolkit for Python

# The entire package is licensed with both licenses, see LICENSE file
License:        ISC
URL:            http://www.dnspython.org

Source0:        https://github.com/rthalley/%{pypi_name}/archive/v%{version}/%{pypi_name}-%{version}.tar.gz
BuildArch:      noarch

BuildRequires:  python3-devel
BuildRequires:  pyproject-rpm-macros
BuildRequires:  python3-pytest

%global _description %{expand:
dnspython is a DNS toolkit for Python. It supports almost all record
types. It can be used for queries, zone transfers, and dynamic
updates. It supports TSIG authenticated messages and EDNS0.

dnspython provides both high and low level access to DNS. The high
level classes perform queries for data of a given name, type, and
class, and return an answer set. The low level classes allow direct
manipulation of DNS zones, messages, names, and records.
}

%description %_description
%package -n python3-dns
Summary:        %{summary}

%description -n python3-dns %_description

%generate_buildrequires
%pyproject_buildrequires -r -x dnssec -x idna %{?with_trio:-x trio} %{?with_doh:-x doh}

%prep
%autosetup -p1 -n %{pypi_name}-%{version}

# strip exec permissions so that we don't pick up dependencies from docs
find examples -type f | xargs chmod a-x

# Allow newer cryptography and requests-toolbelt
sed -i 's/cryptography = {version=">=2.6,<40.0"/cryptography = {version=">=2.6,<42.0"/' pyproject.toml
sed -i 's/requests-toolbelt = {version=">=0.9.1,<0.11.0"/requests-toolbelt = {version=">=0.9.1,<=1.0.0"/' pyproject.toml

%build
%pyproject_wheel

%install
%pyproject_install
%pyproject_save_files dns

%check
export OPENSSL_ENABLE_SHA1_SIGNATURES=yes
%if 0
%pytest
%endif

%files -n python3-dns -f %{pyproject_files}
%license LICENSE
%doc README.md examples
%pycached %exclude %{python3_sitelib}/dns/_trio_backend.py

%pyproject_extras_subpkg -n python3-dns dnssec idna

%if %{with doh}
%pyproject_extras_subpkg -n python3-dns doh
%endif

%if %{with trio}
%pyproject_extras_subpkg -n python3-dns trio
%pycached %{python3_sitelib}/dns/_trio_backend.py
%endif

%changelog
* Wed Mar 13 2024 mgb01105731 <mgb01105731@alibaba-inc.com> - 2.4.1-1
- Update to 2.4.1

* Sat Apr 8 2023 Funda Wang <fundawang@yeah.net> - 2.3.0-1
- New version 2.3.0
- Disable test as it requires valid /etc/resolv.conf, which does not
  exist in current build system

* Sat Dec 17 2022 Chunmei Xu <xuchunmei@linux.alibaba.com> - 2.2.1-2
- rebuild with python-cryptography update

* Fri Jul 15 2022 happy_orange <songnannan@linux.alibaba.com> - 2.2.1-1
- Init pacakge from upstream
